==> beagle-2.1.5.tar.gz: beagle-2.1.5/beagle/src/Object.cpp <==
/*
 *  Open BEAGLE
 *  Copyright (C) 2001-2004 by Christian Gagne and Marc Parizeau
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Contact:
 *  Laboratoire de Vision et Systemes Numeriques
 *  Departement de genie electrique et de genie informatique
 *  Universite Laval, Quebec, Canada, G1K 7P4
 *  http://vision.gel.ulaval.ca
 *
 */

/*!
 *  \file   beagle/src/Object.cpp
 *  \brief  Source code of class Object.
 *  \author Christian Gagne
 *  \author Marc Parizeau
 *  $Revision: 1.4 $
 *  $Date: 2004/04/25 23:12:21 $
 */

#include "beagle/Beagle.hpp"

#include <sstream>

using namespace Beagle;


/*!
 *  \brief Default constructor.
 */
Object::Object() :
  mRefCounter(0)
{ }


/*!
 *  \brief Copy constructor.
 *  \param inOriginal Object to copy.
 */
Object::Object(const Object& inOriginal) :
  mRefCounter(0)
{ }


/*!
 *  \brief Destructor.
 *  \throw Beagle::ObjectException If reference counter is not equal to zero.
 */
Object::~Object()
{
#ifndef BEAGLE_NDEBUG
  if(mRefCounter != 0) {
    std::string lMessage = "Reference counter of actual object is non-zero (value: ";
    lMessage += int2str(mRefCounter);
    lMessage += ")";
    throw Beagle_InternalExceptionM(lMessage);
  }
#endif // BEAGLE_NDEBUG
}


/*!
 *  \brief Copy operator of Object.
 *  \param inOriginal Original object to copy.
 *  \return Actual object.
 */
Object& Object::operator=(const Object& inOriginal)
{
  return *this;
}


/*!
 *  \brief  Test if an object is equal to another.
 *  \param  inRightObj Object to be compare to.
 *  \return True if actual object is equal to right object, false if not.
 *  \throw  Beagle::ObjectException If the method is not overdefined in a subclass.
 */
bool Object::isEqual(const Object& inRightObj) const
{
  throw Beagle_UndefinedMethodInternalExceptionM("isEqual","Object");
  return false;
}


/*!
 *  \brief  Test if an object is less than another.
 *  \param  inRightObj Object to be compare to.
 *  \return True if actual object is less than right object, false if not.
 *  \throw  Beagle::ObjectException If the method is not overdefined in a subclass.
 */
bool Object::isLess(const Object& inRightObj) const
{
  throw Beagle_UndefinedMethodInternalExceptionM("isLess","Object");
  return false;
}


/*!
 *  \brief Extract Object from a Beagle input stream.
 *  \param inNode XML node to read the object from.
 *  \throw Beagle::ObjectException If the method is not overdefined in a subclass.
 */
void Object::read(PointerT<XMLNode,Object::Handle>& inNode)
{
  throw Beagle_UndefinedMethodInternalExceptionM("read","Object");
}


/*!
 *  \brief Transform an Object into a linear string (using write method).
 *  \return String representing the Object.
 */
std::string Object::serialize() const
{
  std::ostringstream lOSS;
  XMLStreamer lStreamer(lOSS, 0);
  write(lStreamer);
  return lOSS.str();
}


/*!
 *  \brief Insert an Object into a Beagle output stream.
 *  \param ioStreamer XML streamer to write the object into.
 *  \throw  Beagle::ObjectException If the method is not overdefined in a subclass.
 */
void Object::write(XMLStreamer& ioStreamer) const
{
  throw Beagle_UndefinedMethodInternalExceptionM("write","Object");
}

==> beagle-2.2.0.tar.gz: beagle-2.2.0/beagle/src/Object.cpp <==
/*
 *  Open BEAGLE
 *  Copyright (C) 2001-2004 by Christian Gagne and Marc Parizeau
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  Contact:
 *  Laboratoire de Vision et Systemes Numeriques
 *  Departement de genie electrique et de genie informatique
 *  Universite Laval, Quebec, Canada, G1K 7P4
 *  http://vision.gel.ulaval.ca
 *
 */

/*!
 *  \file   beagle/src/Object.cpp
 *  \brief  Source code of class Object.
 *  \author Christian Gagne
 *  \author Marc Parizeau
 *  $Revision: 1.5 $
 *  $Date: 2004/10/25 20:45:32 $
 */

#include "beagle/Beagle.hpp"

#include <sstream>

using namespace Beagle;


/*!
 *  \brief Default constructor.
 */
Object::Object() :
  mRefCounter(0)
{ }


/*!
 *  \brief Copy constructor.
 *  \param inOriginal Object to copy.
 */
Object::Object(const Object& inOriginal) :
  mRefCounter(0)
{ }


/*!
 *  \brief Destructor.
 *  \throw Beagle::InternalException If reference counter is not equal to zero.
 */
Object::~Object()
{
#ifndef BEAGLE_NDEBUG
  if(mRefCounter != 0) {
    std::string lMessage = "Reference counter of actual object is non-zero (value: ";
    lMessage += int2str(mRefCounter);
    lMessage += ")";
    throw Beagle_InternalExceptionM(lMessage);
  }
#endif // BEAGLE_NDEBUG
}


/*!
 *  \brief Copy operator of Object.
 *  \param inOriginal Original object to copy.
 *  \return Actual object.
 */
Object& Object::operator=(const Object& inOriginal)
{
  return *this;
}


/*!
 *  \brief  Test if an object is equal to another.
 *  \param  inRightObj Object to be compare to.
 *  \return True if actual object is equal to right object, false if not.
 *  \throw  Beagle::InternalException If the method is not overdefined in a subclass.
 */
bool Object::isEqual(const Object& inRightObj) const
{
  throw Beagle_UndefinedMethodInternalExceptionM("isEqual","Object");
  return false;
}


/*!
 *  \brief  Test if an object is less than another.
 *  \param  inRightObj Object to be compare to.
 *  \return True if actual object is less than right object, false if not.
 *  \throw  Beagle::InternalException If the method is not overdefined in a subclass.
 */
bool Object::isLess(const Object& inRightObj) const
{
  throw Beagle_UndefinedMethodInternalExceptionM("isLess","Object");
  return false;
}


/*!
 *  \brief Extract Object from a Beagle input stream.
 *  \param inNode XML node to read the object from.
 *  \throw Beagle::InternalException If the method is not overdefined in a subclass.
 */
void Object::read(PointerT<XMLNode,Object::Handle>& inNode)
{
  throw Beagle_UndefinedMethodInternalExceptionM("read","Object");
}


/*!
 *  \brief Transform an Object into a linear string (using write method).
 *  \return String representing the Object.
 */
std::string Object::serialize() const
{
  std::ostringstream lOSS;
  XMLStreamer lStreamer(lOSS, 0);
  write(lStreamer);
  return lOSS.str();
}


/*!
 *  \brief Insert an Object into a Beagle output stream.
 *  \param ioStreamer XML streamer to write the object into.
 *  \throw  Beagle::InternalException If the method is not overdefined in a subclass.
 */
void Object::write(XMLStreamer& ioStreamer) const
{
  throw Beagle_UndefinedMethodInternalExceptionM("write","Object");
}
